@@ -1,3 +1,9 @@
+'''
+@author: renqiukai
+@Date: 2020-05-29 10:30:41
+@Description: 
+@LastEditTime: 2020-06-10 18:32:44
+'''
 # 开放平台接口基类
 import requests
 from requests_toolbelt.multipart.encoder import MultipartEncoder
@@ -6,7 +12,7 @@ import json
 
 def request_accesstoken(acc: str, pwd: str) -> str:
     # 请求accesstooke函数
-    url = "http://bms.microc.cn/shopguide/api/auth/logon"
+    url = "http://bms.microc.cn/shopguide/api/auth/logonweb"
     data = {}
     data["loginName"] = acc
     data["password"] = pwd
